/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include <project.h>
#include "oled.h"
#include "smiley.h"


//======================================
// oled struct
//======================================




oled_t oled;        //declare the oled_t struct

int main()
{
    CyGlobalIntEnable; /* Enable global interrupts. */
    
    I2C_Start();        //start the I2C master
    
    CyDelay(25);       //delay for a bit to let the bus and OLED start before trying to run things 
                       //if this is not included, you'll have to hit the reset button after connecting to power
    
    oled_Init(&oled, 0x3C, I2C_MasterSendStart, I2C_MasterSendStop, I2C_MasterWriteByte);   //initializes the oled object
    
    /* &oled is the pointer to the oled struct and must be entered for every API call.
    0x3C is the I2C address of the OLED.
    The other arguments are function pointers for the I2C Master API. Since PSoC Creator lays these out in memory at build
    time and the schematic macro component can be renamed, this must be done.
    
    The reason an Init function is needed after the variable declaration is that c does not support classes.
    An analog to a class can be made using structs and constructor functions, with functions instead of methods, as is done
    in the graphics library.
    
    See the graphics library manual for more information.
    */
    
    oled_Clear(&oled);          //clear the screen
    oled_SetBkColor(&oled, 0);  //set the background color to 0, meaning black
    oled_SetColor(&oled, 1);    //set the foreground color to 1, meaning white
    oled_SetPenSize(&oled, 0);  //set the pen size to 0, meaning 1 pixel
    oled_DrawCircle(&oled, 64, 32, 20);     //draw a circle centered at 64, 32 with a radius of 20 pixels (the pen is cenetered at a 20 pixel distance)

    for(;;)
    {
        //every 2.5 seconds, alternate between a circle and "6.115 is cool!"
        
        CyDelay(2500);
        
        oled_Clear(&oled);                      //clear the screen
        oled_DispString(&oled, 0, 0, "6.115");  //draw "6.115" with the top left corner of it at 0, 0
        oled_DispString(&oled, 0, 16, "is");    //The library doesn't have text wrapping, so do it manually
        oled_DispString(&oled, 0, 32, "cool!"); //each character is 16 px tall, so increment by 16 between lines
        
        CyDelay(2500);
        
        oled_Clear(&oled);                      //clear the screen
        oled_DrawCircle(&oled, 64, 32, 20);     //draw a circle of radius 20 at 64, 32 on the screen
        
        CyDelay(2500);
        oled_SetBmMode(&oled, OLED_BM_NORMAL);  //set the bitmap mode to normal
        oled_DispBitmap(&oled, 61, 29, smiley_bits, smiley_width, smiley_height);   //draw the smiley bitmap with its top left corner at 61, 29
    }
}


/* [] END OF FILE */
